%define anolis_release 1
%global selinuxmodulever	1.0.2
%global selinuxmoduledir	%{name}-selinux-%{selinuxmodulever}
%define username   memcached
%define groupname  memcached
%bcond_without sasl
%bcond_with seccomp
%bcond_without tls
%bcond_with tests

Name:           memcached
Version:        1.6.22
Release:        %{anolis_release}%{?dist}
Epoch:          0
Summary:        High Performance, Distributed Memory Object Cache
License:        BSD-3-clause
URL:            https://www.memcached.org/
Source0:        https://www.memcached.org/files/%{name}-%{version}.tar.gz
Source1:        memcached.sysconfig
Source2:        https://releases.pagure.org/memcached-selinux/memcached-selinux-%{selinuxmodulever}.tar.gz
Source3:	memcached.conf

Patch0:         memcached-unit.patch

BuildRequires:  make gcc libevent-devel systemd
BuildRequires:  perl-generators perl(Test::More), perl(Test::Harness)
%if %{with sasl}
BuildRequires: cyrus-sasl-devel
%endif
%if %{with seccomp}
BuildRequires: libseccomp-devel
%endif
%if %{with tls}
BuildRequires: openssl-devel
%endif

Requires(pre):  shadow-utils
Requires: (%{name}-selinux if selinux-policy-targeted)
%{?systemd_requires}

%description
memcached is a high-performance, distributed memory object caching
system, generic in nature, but intended for use in speeding up dynamic
web applications by alleviating database load.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary: Files needed for development using memcached protocol
Requires: %{name} = %{EVR}

%description devel
Install memcached-devel if you are developing C/C++ applications that require
access to the memcached binary include files.

%package selinux
Summary: Selinux policy module
License: GPLv2
BuildRequires: selinux-policy
%{?selinux_requires}

%description selinux
Install memcached-selinux to ensure your system contains the latest SELinux policy
optimised for use with this version of memcached.

%prep
%autosetup -p1 -b 2

%build
%configure \
  %{?with_sasl: --enable-sasl --enable-sasl-pwdb} \
  %{?with_seccomp: --enable-seccomp} \
  %{?with_tls: --enable-tls}

%make_build

pushd ../%{selinuxmoduledir}
%make_build
popd

%check
%if %{with tests}
rm -f t/whitespace.t
if [ `id -u` -ne 0 ]; then
  rm -f t/daemonize.t t/watcher.t t/expirations.t
fi
make test
%endif

%install
%make_install

rm -f %{buildroot}/%{_bindir}/memcached-debug
install -Dp -m0755 scripts/memcached-tool %{buildroot}%{_bindir}/memcached-tool
install -Dp -m0644 scripts/memcached-tool.1 %{buildroot}%{_mandir}/man1/memcached-tool.1
install -Dp -m0644 scripts/memcached.service %{buildroot}%{_unitdir}/memcached.service
install -Dp -m0644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/sysconfig/%{name}

pushd ../%{selinuxmoduledir}
mkdir -p %{buildroot}%{_datadir}/selinux/packages
install -d -p %{buildroot}%{_datadir}/selinux/devel/include/contrib
install -m 0644 %{name}.pp.bz2 %{buildroot}%{_datadir}/selinux/packages
popd

install -p -D -m 0644 %{SOURCE3} %{buildroot}%{_sysusersdir}/memcached.conf

%pre
%sysusers_create_compat %{SOURCE3}

%pre selinux
%selinux_relabel_pre -s targeted

%post
%systemd_post memcached.service

%post selinux
%selinux_modules_install -s targeted -p 200 %{_datadir}/selinux/packages/%{name}.pp.bz2 &> /dev/null

%preun
%systemd_preun memcached.service

%postun
%systemd_postun_with_restart memcached.service

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s targeted -p 200 %{name}
fi

%posttrans selinux
%selinux_relabel_post -s targeted &> /dev/null

%files
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/memcached-tool
%{_bindir}/memcached
%{_unitdir}/memcached.service
%{_mandir}/man1/memcached-tool.1*
%{_mandir}/man1/memcached.1*
%{_sysusersdir}/memcached.conf

%files devel
%{_includedir}/memcached/*

%files selinux
%attr(0644,root,root) %{_datadir}/selinux/packages/%{name}.pp.bz2
%ghost %{_sharedstatedir}/selinux/targeted/active/modules/200/%{name}
%license ../%{selinuxmoduledir}/COPYING

%files doc
%doc README.md NEWS COPYING ChangeLog AUTHORS
%doc doc/CONTRIBUTORS doc/*.txt

%changelog
* Wed Nov 01 2023 Funda Wang <fundawang@yeah.net> - 0:1.6.22-1
- New version 1.6.22

* Mon Aug 21 2023 happy_orange <songnannan@linux.alibaba.com> - 1.6.21-1
- update to 1.6.21

* Fri Apr 14 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.6.18-2
- Refactor the specfile

* Fri Jan 20 2023 Funda Wang <fundawang@yeah.net> - 1.6.18-1
- New version 1.6.18

* Wed Aug 31 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.6.16-1
- update memcached to 1.6.16

* Fri Jun 10 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.6.15-1
- Init from upstream version 1.6.15
